| climate | R Documentation |
A dataframe containing palaeoclimate data at 1 ky temporal resolution with the following columns:
data(climate)
dataframe with 6 columns and 800 rows.
age in kiloyears before present (ky BP).
temperatureAverage average annual temperature in degrees Celsius.
rainfallAverage average annual precipitation in millimetres per day (mm/day).
temperatureWarmestMonth average temperature of the warmest month, in degrees Celsius.
temperatureColdestMonth average temperature of the coldest month, in degrees Celsius.
oxigenIsotope delta O18, global ratio of stable isotopes in the sea floor, see http://lorraine-lisiecki.com/stack.html for further details.
Blas M. Benito <blasbenito@gmail.com>
Other example_data:
palaeodata,
palaeodataLagged,
palaeodataMemory,
pollen
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.