View source: R/experimentToTable.R
| experimentToTable | R Documentation |
runExperiment into a long table.Takes the output of runExperiment, extracts the dataframes containing the ecological memory patterns generated by computeMemory, and binds them together into a single dataframe ready for further analyses or plotting.
experimentToTable(experiment.output = NULL, parameters.file = NULL)
experiment.output |
list, output of |
parameters.file |
dataframe of simulation parameters. Default: |
This function is used internally by plotExperiment, but it is also available to users in case they want to do other kinds of analyses or plots with the data.
A dataframe.
Blas M. Benito <blasbenito@gmail.com>
runExperiment, plotExperiment
Other virtualPollen:
plotExperiment(),
runExperiment()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.