| palaeodataLagged | R Documentation |
prepareLaggedData.A dataframe resulting from the application of prepareLaggedData to the dataset palaeodata. The dataframe columns are named using the pattern VariableName__LagValue:
data(palaeodataLagged)
dataframe with 19 columns and 3988 rows.
pollen.pinus__0 numeric, values of the response variable (pollen counts of Pinus) at lag 0 (current time). This column is used as the response variable by computeMemory.
pollen.pinus__0.2-1 numeric, time-delayed values of the response for lags 0.2 to 1 (in ky). These columns represent the endogenous ecological memory.
climate.temperatureAverage__0 numeric, temperature values at lag 0 (concurrent effect).
climate.rainfallAverage__0 numeric, rainfall values at lag 0 (concurrent effect).
climate.temperatureAverage__0.2-1 numeric, time-delayed temperature values for lags 0.2 to 1 (exogenous memory).
climate.rainfallAverage__0.2-1 numeric, time-delayed rainfall values for lags 0.2 to 1 (exogenous memory).
time numeric, the time/age column.
The dataframe has attributes response and drivers that are automatically used by computeMemory.
Blas M. Benito <blasbenito@gmail.com>
Other example_data:
climate,
palaeodata,
palaeodataMemory,
pollen
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.