View source: R/runExperiment.R
| runExperiment | R Documentation |
virtualPollen package.Applies computeMemory to assess ecological memory on a large set of virtual pollen curves.
runExperiment(
simulations.file = NULL,
selected.rows = NULL,
selected.columns = NULL,
parameters.file = NULL,
parameters.names = NULL,
driver.column = NULL,
response.column = "Pollen",
subset.response = "none",
time.column = "Time",
time.zoom = NULL,
lags = NULL,
repetitions = 10
)
simulations.file |
List of dataframes produced by |
selected.rows |
Numeric vector indicating which virtual taxa (list elements)
from |
selected.columns |
Numeric vector indicating which sampling schemes (columns)
from |
parameters.file |
Dataframe of simulation parameters produced by
|
parameters.names |
Character vector of column names from |
driver.column |
Character vector of column names representing environmental
drivers in the simulation dataframes. Common choices: |
response.column |
Character string naming the response variable column in the
simulation dataframes. Use |
subset.response |
character string, one of "up", "down" or "none", triggers the subsetting of the input dataset. "up" only models ecological memory on cases where the response's trend is positive, "down" selects cases with negative trends, and "none" selects all cases. Default: |
time.column |
character string, name of the time/age column. Usually, "Time". Default: |
time.zoom |
numeric vector with two numbers defining the time/age extremes of the time interval of interest. Default: |
lags |
numeric vector, lags to be used in the equation, in the same units as |
repetitions |
integer, number of random forest models to fit. Default: |
A list with 2 slots:
names matrix of character strings, with as many rows and columns as simulations.file. Each cell holds a simulation name to be used afterwards, when plotting the results of the ecological memory analysis.
output a list with as many rows and columns as simulations.file. Each slot holds a an output of computeMemory.
memory dataframe with five columns:
Variable character, names and lags of the different variables used to model ecological memory.
median numeric, median importance across repetitions of the given Variable according to Random Forest.
sd numeric, standard deviation of the importance values of the given Variable across repetitions.
min and max numeric, percentiles 0.05 and 0.95 of importance values of the given Variable across repetitions.
R2 vector, values of pseudo R-squared value obtained for the Random Forest model fitted on each repetition. Pseudo R-squared is the Pearson correlation between the observed and predicted data.
prediction dataframe, with the same columns as the dataframe in the slot memory, with the median and confidence intervals of the predictions of all random forest models fitted.
multicollinearity multicollinearity analysis on the input data performed with vif_df. A vif value higher than 5 indicates that the given variable is highly correlated with other variables.
Blas M. Benito <blasbenito@gmail.com>
computeMemory
Other virtualPollen:
experimentToTable(),
plotExperiment()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.